@@ -1,6 +1,6 @@
 package Reflex::Base;
 {
-  $Reflex::Base::VERSION = '0.095';
+  $Reflex::Base::VERSION = '0.096';
 }
 # vim: ts=2 sw=2 noexpandtab
 
@@ -26,7 +26,7 @@ Reflex::Base - Base class for reactive (aka, event driven) objects.
 
 =head1 VERSION
 
-This document describes version 0.095, released on March 02, 2012.
+This document describes version 0.096, released on March 06, 2012.
 
 =head1 SYNOPSIS
 
@@ -126,7 +126,7 @@ L<Reflex/TODO>
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Reflex>.
 
 =head1 AUTHOR
 
