@@ -1,6 +1,6 @@
 package Reflex::Event::SigChild;
 {
-  $Reflex::Event::SigChild::VERSION = '0.095';
+  $Reflex::Event::SigChild::VERSION = '0.096';
 }
 
 use Moose;
@@ -29,7 +29,7 @@ __END__
 
 =head1 VERSION
 
-This document describes version 0.095, released on March 02, 2012.
+This document describes version 0.096, released on March 06, 2012.
 
 =head1 SEE ALSO
 
@@ -48,7 +48,7 @@ L<Reflex|Reflex>
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Reflex>.
 
 =head1 AUTHOR
 
