@@ -1,6 +1,6 @@
 package Reflex::Trait::EmitsOnChange;
 {
-  $Reflex::Trait::EmitsOnChange::VERSION = '0.095';
+  $Reflex::Trait::EmitsOnChange::VERSION = '0.096';
 }
 # vim: ts=2 sw=2 noexpandtab
 
@@ -98,7 +98,7 @@ sub emits {
 
 package Moose::Meta::Attribute::Custom::Trait::Reflex::Trait::EmitsOnChange;
 {
-  $Moose::Meta::Attribute::Custom::Trait::Reflex::Trait::EmitsOnChange::VERSION = '0.095';
+  $Moose::Meta::Attribute::Custom::Trait::Reflex::Trait::EmitsOnChange::VERSION = '0.096';
 }
 sub register_implementation { 'Reflex::Trait::EmitsOnChange' }
 
@@ -118,7 +118,7 @@ Reflex::Trait::EmitsOnChange - Emit an event when an attribute's value changes.
 
 =head1 VERSION
 
-This document describes version 0.095, released on March 02, 2012.
+This document describes version 0.096, released on March 06, 2012.
 
 =head1 SYNOPSIS
 
@@ -244,7 +244,7 @@ L<Reflex/TODO>
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Reflex>.
 
 =head1 AUTHOR
 
